//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/List/SamplesQListView.h
//! @brief     Defines class SamplesQListView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_LIST_SAMPLESQLISTVIEW_H
#define BORNAGAIN_GUI_VIEW_LIST_SAMPLESQLISTVIEW_H

#include <QListView>

class SampleItem;
class SamplesQModel;

//! List view to select one sample (left side of layer-oriented sample editor)
class SamplesQListView : public QListView {
    Q_OBJECT
public:
    SamplesQListView();

    void createNewSample();
    void createSampleFromLibrary(const QString& classname, const QString& title,
                                 const QString& description);
    void importSampleFromPython();
    void onCurrentChanged(const QModelIndex& index);
    void removeSample(SampleItem* item);
    void copySample(SampleItem* item);
signals:
    void currentSampleChanged(SampleItem* current);

private:
    QAction* createRemoveAction(QObject* parent, SampleItem* item);
    QAction* createCopyAction(QObject* parent, SampleItem* item);

    void showContextMenu(const QPoint& pos);

    SamplesQModel* m_model;
};

#endif // BORNAGAIN_GUI_VIEW_LIST_SAMPLESQLISTVIEW_H
