//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Setup/FrameActions.h
//! @brief     Defines class FrameActions.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SETUP_FRAMEACTIONS_H
#define BORNAGAIN_GUI_VIEW_SETUP_FRAMEACTIONS_H

#include <QAction>
#include <QString>

namespace ActionFactory {

QAction* createCopyAction(const QString& type, QObject* parent = nullptr);
QAction* createRemoveAction(const QString& type, QObject* parent = nullptr);

} // namespace ActionFactory

//! Actions for use in GUI top-level frames. Accessible through global gActions.

class FrameActions {
public:
    FrameActions();

    QAction* toggle_mask_value;
    QAction* raise_mask;
    QAction* lower_mask;
    QAction* delete_mask;

    QAction* delete_projection;

    QAction* reset_view;
    QAction* save_plot;
    QAction* save_projections;

    QAction* toggle_properties_panel;

    QAction* cycle_data2d_edit_mode;

    QAction* new_gisas_instrument;
    QAction* new_offspec_instrument;
    QAction* new_specular_instrument;
    QAction* new_depthprobe_instrument;
    QAction* remove_instrument;
    QAction* copy_instrument;
    QAction* store_in_library_instrument;
    QAction* load_from_library_instrument;
};

extern FrameActions* gActions;

#endif // BORNAGAIN_GUI_VIEW_SETUP_FRAMEINSTRUMENTS_H
